============
``vcd.gtkw``
============

.. automodule:: vcd.gtkw

.. autoclass:: GTKWSave
   :members:

.. autofunction:: make_translation_filter

.. autofunction:: decode_flags

.. autofunction:: encode_flags

.. autodata:: flag_names

.. autodata:: flag_masks

.. autofunction:: spawn_gtkwave_interactive
